@@ -1,15 +1,15 @@
 package Parse::CPAN::Packages::Distribution;
 use strict;
 use base qw( Class::Accessor::Fast );
-__PACKAGE__->mk_accessors(qw( prefix dist version maturity filename
-                              cpanid distvname packages ));
-use vars qw($VERSION);
-$VERSION = '2.12';
+__PACKAGE__->mk_accessors(
+    qw( prefix dist version maturity filename
+        cpanid distvname packages )
+);
 
 sub new {
     my $class = shift;
-    my $self = $class->SUPER::new;
-    $self->packages([]);
+    my $self  = $class->SUPER::new;
+    $self->packages( [] );
     return $self;
 }
 
